$(document).ready(function(){
	
	//Define 
	var file_name = "data/line_data.tsv";
	
	//Define margin
	var margin = {top: 20, right: 150, bottom: 25, left: 60};
	var vis_width = $('.visualization').width() - margin.left - margin.right;
	var vis_height = $('.visualization').height() - margin.top - margin.bottom;

	var parseDate = d3.time.format("%Y-%m-%d-%H").parse;

	//Define x, y scale and color scale
	var x_scale = d3.time.scale().range([0,vis_width]);
	var y_scale = d3.scale.linear().range([vis_height,0]);
	var color = d3.scale.category20() //Check https://github.com/mbostock/d3/wiki/Ordinal-Scales

	//Define axes
	var x_axis = d3.svg.axis().scale(x_scale).orient("bottom");
	var y_axis = d3.svg.axis().scale(y_scale).orient("left");//.ticks(10)

	var line = d3.svg.line().interpolate("basis")
    	.x(function(d) { return x_scale(d.date); })
    	.y(function(d) { return y_scale(d.frequency); });	

	//Append SVG to .vis
	var svg = d3.select('.visualization')
		.append('svg').attr('width',$('.visualization').width()).attr('height',$('.visualization').height())
		.append('g').attr("transform", "translate(" + margin.left + "," + margin.top + ")");

	//Bining data
	d3.tsv(file_name, function(error, data) {
		//If no data
		if (error) throw error;
		
		//Check how many of variables are visualized
		var data_key = Object.keys(data[0]);
		var num_of_element = data_key.length -1;
    var isSelected = [];
    for (index = 0; index < num_of_element; index++) {
      isSelected.push(false);
    }
  		color.domain(d3.keys(data[0]).filter(function(key) { return key !== "date"; }));

  		data.forEach(function(d) {d.date = parseDate(d.date);});

  		var keywords = color.domain().map(function(name) {
    		return {
      			name: name,
      			values: data.map(function(d) {
        			return {date: d.date, frequency: +d[name]};
      			})
    		};
  		});

  		x_scale.domain(d3.extent(data, function(d) { return d.date; }));

  		y_scale.domain([
    		d3.min(keywords, function(c) { return d3.min(c.values, function(v) { return v.frequency; }); }),
    		d3.max(keywords, function(c) { return d3.max(c.values, function(v) { return v.frequency; }); })
  		]);

  		svg.append("g")
      		.attr("class", "x axis")
      		.attr("transform", "translate(0," + vis_height + ")")
      		.call(x_axis);

  		svg.append("g")
      		.attr("class", "y axis")
      		.call(y_axis)
    		.append("text")
      		.attr("transform", "rotate(-90)")
      		.attr("y", 6)
      		.attr("dy", ".71em")
      		.style("text-anchor", "end")
      		.text("Frequency (times)");

  		var keyword = svg.selectAll(".keyword")
      		.data(keywords)
    		.enter().append("g")
      		.attr("class", "ketword");

  		keyword.append("path")
      		.attr("class", "line")
      		.attr("id", function(d,i){return "line"+i;})
      		.attr("stroke-opacity", 0.3)
      		.attr("d", function(d) { return line(d.values); })
      		.style("stroke", function(d) { return color(d.name); });

  		keyword.append("text")
      		.datum(function(d) { return {name: d.name, value: d.values[d.values.length - 1]}; })
      		.attr("transform", function(d,i) { return "translate(" +(x_scale(d.value.date)+10) + "," + (vis_height/num_of_element) * i + ")"; })
      		.attr("class", "keywords")
          .attr("fill", function(d) { return color(d.name); })
          .attr("fill-opacity", 1)
      		.attr("id", function(d,i){return i;})
      		.attr("font-szie", "10px")
      		.attr("x", 3)
      		.attr("dy", ".35em")
      		.text(function(d) { return d.name; })
      		.on("mouseover", function(){
      			$(this).css('cursor', 'pointer');
      			$(".line").attr("stroke-opacity", 0.1);
      			$("#line"+$(this).attr("id")).attr("stroke-opacity", 1);
      		})
          .on("click", function(){
            value = ($(this).attr("id"));
            if (isSelected[value] == true){
              isSelected[value] = false
            }
            else
              isSelected[value] = true
            for (i=0; i<num_of_element;i++){
              selector = "#"+i;
              if (isSelected[i] == true){
                $(selector).attr("fill-opacity", 1);
              }
              else $(selector).attr("fill-opacity", 0.5);
            }
          })
      		.on("mouseout", function(){
            for (i=0; i<num_of_element;i++){
              selector = "#line"+i;
              if (isSelected[i] == true){
                $(selector).attr("stroke-opacity", 1);
              }
              else $(selector).attr("stroke-opacity", 0.1);
            }
      		});
	});
});